@@ -9,6 +9,20 @@ class WaiterTimeout(Exception):
     pass
 
 
+class ContainerBeingKilled(Exception):
+    """Raised by :meth:`Container.spawn_worker` if it has started a ``kill``
+    sequence.
+
+    Entrypoint providers should catch this and react as if they hadn't been
+    available in the first place, e.g. an rpc consumer should probably requeue
+    the message.
+
+    We need this because eventlet may yield during the execution of
+    :meth:`Container.kill`, giving entrypoints a chance to fire before
+    they themselves have been killed.
+    """
+
+
 registry = {}
 
 
@@ -17,7 +31,7 @@ def get_module_path(exc_type):
 
     e.g.::
 
-        >>> get_module_class(MethodNotFound)
+        >>> get_module_path(MethodNotFound)
         >>> "nameko.exceptions.MethodNotFound"
 
     """
